summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--xmake/actions/require/impl/environment.lua6
1 files changed, 3 insertions, 3 deletions
diff --git a/xmake/actions/require/impl/environment.lua b/xmake/actions/require/impl/environment.lua
index 5adece2ca..7104d1e8e 100644
--- a/xmake/actions/require/impl/environment.lua
+++ b/xmake/actions/require/impl/environment.lua
@@ -37,9 +37,9 @@ function enter()
-- set search paths of toolchains
environment.enter("toolchains")
- -- unzip is necessary
- if not find_tool("unzip") then
- raise("unzip not found! we need install it first")
+ -- unzip or 7zip is necessary
+ if not find_tool("unzip") and not find_tool("7z") then
+ raise("unzip or 7zip not found! we need install it first")
end
-- enter the environments of git and 7z